@@ -60,7 +60,7 @@ static void     verify_clicked                        (GtkWidget              *b
                                                        GladeProjectProperties *properties);
 static void     on_domain_entry_changed               (GtkWidget              *entry,
                                                        GladeProjectProperties *properties);
-static void     target_button_clicked                 (GtkWidget              *widget,
+static void     target_combobox_changed               (GtkWidget              *widget,
                                                        GladeProjectProperties *properties);
 static void     on_glade_project_properties_hide      (GtkWidget              *widget,
                                                        GladeProjectProperties *properties);
@@ -92,14 +92,14 @@ static void     project_css_provider_path_changed     (GladeProject           *p
                                                        GParamSpec             *pspec,
                                                        GladeProjectProperties *properties);
 
-struct _GladeProjectPropertiesPrivate
+typedef struct
 {
   GladeProject *project;
 
   /* Properties */
   GtkWidget *project_wide_radio;
   GtkWidget *toplevel_contextual_radio;
-  GtkWidget *toolkit_box;
+  GtkWidget *toolkit_grid;
 
   GtkWidget *resource_default_radio;
   GtkWidget *resource_relative_radio;
@@ -125,6 +125,14 @@ struct _GladeProjectPropertiesPrivate
   GtkTextBuffer  *license_textbuffer;
   
   gboolean ignore_ui_cb;
+} GladeProjectPropertiesPrivate;
+
+
+struct _GladeProjectProperties
+{
+  GtkDialog parent;
+
+  GladeProjectPropertiesPrivate *priv; /* Unused */
 };
 
 enum
@@ -134,6 +142,7 @@ enum
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GladeProjectProperties, glade_project_properties, GTK_TYPE_DIALOG);
+#define GLADE_PROJECT_PROPERTIES_PRIVATE(o) ((GladeProjectPropertiesPrivate *) glade_project_properties_get_instance_private((GladeProjectProperties*)o))
 
 /********************************************************
  *                  Class/Instance Init                 *
@@ -141,9 +150,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (GladeProjectProperties, glade_project_properties, GT
 static void
 glade_project_properties_init (GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv;
-
-  properties->priv = priv = glade_project_properties_get_instance_private (properties);
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   priv->target_radios = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                g_free, NULL);
@@ -184,7 +191,7 @@ glade_project_properties_class_init (GladeProjectPropertiesClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, domain_entry);
   gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, template_checkbutton);
   gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, template_combobox);
-  gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, toolkit_box);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, toolkit_grid);
   gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, css_filechooser);
   gtk_widget_class_bind_template_child_private (widget_class, GladeProjectProperties, css_checkbutton);
 
@@ -224,100 +231,98 @@ static void
 glade_project_properties_finalize (GObject *object)
 {
   GladeProjectProperties        *properties = GLADE_PROJECT_PROPERTIES (object);
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   g_hash_table_destroy (priv->target_radios);
 
   G_OBJECT_CLASS (glade_project_properties_parent_class)->finalize (object);
 }
 
+static void
+combobox_populate_from_catalog (GladeProjectProperties *properties,
+                                GtkWidget              *combobox,
+                                GladeCatalog           *catalog)
+{
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
+  GladeProject *project = priv->project;
+  gint minor, major, position;
+  GList *targets;
+
+  glade_project_get_target_version (project,
+                                    glade_catalog_get_name (catalog),
+                                    &major, &minor);
+
+  for (targets = glade_catalog_get_targets (catalog), position = 0;
+       targets; targets = targets->next, position++)
+    {
+      GladeTargetableVersion *version = targets->data;
+      g_autofree gchar *name = g_strdup_printf ("%d.%d",
+                                     version->major,
+                                     version->minor);
+
+      gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT(combobox), position, name);
+      if (major == version->major && minor == version->minor)
+        gtk_combo_box_set_active (GTK_COMBO_BOX(combobox), position);
+
+      g_signal_connect (G_OBJECT (combobox), "changed",
+                        G_CALLBACK (target_combobox_changed), properties);
+      g_object_set_data (G_OBJECT (combobox), "catalog",
+                         (gchar *) glade_catalog_get_name (catalog));
+    }
+
+  g_hash_table_insert (priv->target_radios,
+                       g_strdup (glade_catalog_get_name (catalog)),
+                       combobox);
+}
+
 static void
 target_version_box_fill (GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
-  GladeProject *project = priv->project;
-  GtkWidget *vbox = priv->toolkit_box;
-  GtkWidget *label, *active_radio, *target_radio, *hbox;
-  GList *list, *targets;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
+  GtkWidget *grid = priv->toolkit_grid;
+  GtkWidget *label, *combobox;
+  static gint n_columns = 3;
+  gint i, j, left;
+  GList *list;
 
-  /* Add stuff to vbox */
-  for (list = glade_app_get_catalogs (); list; list = g_list_next (list))
+
+  /* Add stuff to the toolkit grid */
+  for (list = glade_app_get_catalogs (), i = 0, j = 0; list;
+       list = g_list_next (list))
     {
       GladeCatalog *catalog = list->data;
-      gint minor, major;
 
       /* Skip if theres only one option */
       if (g_list_length (glade_catalog_get_targets (catalog)) <= 1)
         continue;
 
-      glade_project_get_target_version (project,
-                                        glade_catalog_get_name (catalog),
-                                        &major, &minor);
-
       /* Special case to mark GTK+ in upper case */
       if (strcmp (glade_catalog_get_name (catalog), "gtk+") == 0)
-        label = gtk_label_new ("GTK+");
+        label = gtk_label_new ("GTK");
       else
         label = gtk_label_new (glade_catalog_get_name (catalog));
+
+      left = (i % n_columns) * 2;
       gtk_widget_set_halign (label, GTK_ALIGN_START);
-
+      gtk_grid_attach (GTK_GRID (grid), label, left, j, 1, 1);
       gtk_widget_show (label);
-      gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 2);
-      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
-      active_radio = target_radio = NULL;
+      combobox = gtk_combo_box_text_new ();
+      gtk_widget_set_margin_end (combobox, 8);
+      combobox_populate_from_catalog (properties, combobox, catalog);
+      gtk_grid_attach (GTK_GRID (grid), combobox, left + 1, j, 1, 1);
+      gtk_widget_show (combobox);
 
-      for (targets = glade_catalog_get_targets (catalog);
-           targets; targets = targets->next)
-        {
-          GladeTargetableVersion *version = targets->data;
-          gchar *name = g_strdup_printf ("%d.%d",
-                                         version->major,
-                                         version->minor);
-
-          if (!target_radio)
-            target_radio = gtk_radio_button_new_with_label (NULL, name);
-          else
-            target_radio =
-                gtk_radio_button_new_with_label_from_widget
-                (GTK_RADIO_BUTTON (target_radio), name);
-          g_free (name);
-
-          g_signal_connect (G_OBJECT (target_radio), "clicked",
-                            G_CALLBACK (target_button_clicked), properties);
-
-          g_object_set_data (G_OBJECT (target_radio), "version", version);
-          g_object_set_data (G_OBJECT (target_radio), "catalog",
-                             (gchar *) glade_catalog_get_name (catalog));
-
-          gtk_widget_show (target_radio);
-          gtk_box_pack_end (GTK_BOX (hbox), target_radio, TRUE, TRUE, 2);
-
-          if (major == version->major && minor == version->minor)
-            active_radio = target_radio;
-
-        }
-
-      if (active_radio)
-        {
-          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_radio), TRUE);
-          g_hash_table_insert (priv->target_radios,
-                               g_strdup (glade_catalog_get_name (catalog)),
-                               gtk_radio_button_get_group (GTK_RADIO_BUTTON
-                                                           (active_radio)));
-        }
-      else
-        g_warning ("Corrupt catalog versions");
-
-      gtk_widget_show (hbox);
-      gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 2);
+      i++;
+      if (i % n_columns == 0)
+        j++;
     }
 }
 
 static void
 update_prefs_for_resource_path (GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   const gchar *resource_path;
 
   resource_path = glade_project_get_resource_path (priv->project);
@@ -359,7 +364,7 @@ static void
 glade_project_properties_set_project (GladeProjectProperties *properties,
                                       GladeProject           *project)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   /* No strong reference, we belong to the project */
   g_assert (priv->project == NULL);
@@ -408,26 +413,29 @@ glade_project_properties_set_property (GObject *object,
  *                     Callbacks                        *
  ********************************************************/
 static void
-target_button_clicked (GtkWidget              *widget,
-                       GladeProjectProperties *properties)
+target_combobox_changed (GtkWidget              *widget,
+                         GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
-  GladeTargetableVersion        *version;
-  gchar                         *catalog;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
+  g_autofree gchar *version = NULL;
+  gchar *catalog;
+  gint major, minor;
 
   if (priv->ignore_ui_cb)
     return;
 
-  version = g_object_get_data (G_OBJECT (widget), "version");
+  version = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
   catalog = g_object_get_data (G_OBJECT (widget), "catalog");
-  glade_command_set_project_target (priv->project, catalog, version->major, version->minor);
+
+  if (sscanf (version, "%d.%d", &major, &minor) == 2)
+    glade_command_set_project_target (priv->project, catalog, major, minor);
 }
 
 static void
 resource_default_toggled (GtkWidget              *widget,
                           GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (priv->ignore_ui_cb || 
       !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
@@ -440,7 +448,7 @@ static void
 resource_relative_toggled (GtkWidget              *widget,
                            GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkToggleButton *toggle = GTK_TOGGLE_BUTTON (widget);
   
   if (priv->ignore_ui_cb || !gtk_toggle_button_get_active (toggle))
@@ -456,7 +464,7 @@ static void
 resource_fullpath_toggled (GtkWidget              *widget,
                            GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkToggleButton *toggle = GTK_TOGGLE_BUTTON (widget);
 
   if (priv->ignore_ui_cb || !gtk_toggle_button_get_active (toggle))
@@ -488,7 +496,7 @@ on_relative_path_entry_insert_text (GtkEditable            *editable,
 static void
 on_relative_path_entry_changed (GtkEntry *entry, GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (priv->ignore_ui_cb)
     return;
@@ -499,7 +507,7 @@ on_relative_path_entry_changed (GtkEntry *entry, GladeProjectProperties *propert
 static void
 resource_full_path_set (GtkFileChooserButton *button, GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   gchar *text;
   
   if (priv->ignore_ui_cb)
@@ -514,7 +522,7 @@ static void
 on_template_combo_box_changed (GtkComboBox            *combo,
                                GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkTreeIter iter;
 
   if (priv->ignore_ui_cb)
@@ -538,7 +546,7 @@ static void
 on_template_checkbutton_toggled (GtkToggleButton        *togglebutton,
                                  GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (priv->ignore_ui_cb)
     return;
@@ -595,7 +603,7 @@ template_visible_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 static GtkTreeModel *
 glade_project_toplevel_model_filter_new (GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkTreeModel *model;
 
   model = gtk_tree_model_filter_new (GTK_TREE_MODEL (priv->project), NULL);
@@ -607,7 +615,7 @@ glade_project_toplevel_model_filter_new (GladeProjectProperties *properties)
 static void
 verify_clicked (GtkWidget *button, GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (glade_project_verify (priv->project, FALSE,
                             GLADE_VERIFY_VERSIONS     |
@@ -626,7 +634,7 @@ verify_clicked (GtkWidget *button, GladeProjectProperties *properties)
 static void
 on_domain_entry_changed (GtkWidget *entry, GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (priv->ignore_ui_cb)
     return;
@@ -844,7 +852,7 @@ string_count_new_lines (const gchar *str)
 static void
 gpp_update_license (GladeProjectProperties *properties, gchar *license)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   const gchar *name, *description;
   gchar *copyright, *authors;
 
@@ -885,7 +893,8 @@ gpp_update_license (GladeProjectProperties *properties, gchar *license)
 static void
 on_license_data_changed (GladeProjectProperties *properties)
 {
-  const gchar *id = gtk_combo_box_get_active_id (properties->priv->license_comboboxtext);
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
+  const gchar *id = gtk_combo_box_get_active_id (priv->license_comboboxtext);
   gchar *license;
 
   if ((license = gpp_get_license_from_id (id)))
@@ -896,7 +905,7 @@ static void
 on_license_comboboxtext_changed (GtkComboBox            *widget,
                                  GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   gchar *license;
 
   if ((license = gpp_get_license_from_id (gtk_combo_box_get_active_id (widget))))
@@ -917,7 +926,7 @@ static void
 on_glade_project_properties_hide (GtkWidget              *widget,
                                   GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkTextIter start, end;
   gchar *license;
 
@@ -933,7 +942,7 @@ on_glade_project_properties_hide (GtkWidget              *widget,
 static void
 on_css_checkbutton_toggled (GtkWidget *widget, GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   if (priv->ignore_ui_cb)
     return;
@@ -953,7 +962,7 @@ static void
 on_css_filechooser_file_set (GtkFileChooserButton   *widget,
                              GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   const gchar *path;
 
   if (priv->ignore_ui_cb)
@@ -971,17 +980,15 @@ static void
 project_targets_changed (GladeProject           *project,
                          GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GList *list;
-  GSList *radios, *l;
-
   priv->ignore_ui_cb = TRUE;
 
   /* For each catalog */
   for (list = glade_app_get_catalogs (); list; list = g_list_next (list))
     {
-      GladeTargetableVersion *version;
       GladeCatalog *catalog = list->data;
+      GtkComboBox *combobox;
       gint minor, major;
 
       /* Skip if theres only one option */
@@ -995,20 +1002,11 @@ project_targets_changed (GladeProject           *project,
 
       /* Fetch the radios for this catalog  */
       if (priv->target_radios &&
-          (radios = g_hash_table_lookup (priv->target_radios, glade_catalog_get_name (catalog))) != NULL)
+          (combobox = g_hash_table_lookup (priv->target_radios, glade_catalog_get_name (catalog))) != NULL)
         {
-          for (l = radios; l; l = l->next)
-            {
-              GtkWidget *radio = l->data;
-
-              /* Activate the appropriate button for the project/catalog */
-              version = g_object_get_data (G_OBJECT (radio), "version");
-              if (version->major == major && version->minor == minor)
-                {
-                  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
-                  break;
-                }
-            }
+          g_autofree gchar *id = NULL;
+          id = g_strdup_printf ("%d.%d", major, minor);
+          gtk_combo_box_set_active_id(GTK_COMBO_BOX(combobox), id);
         }
     }
   priv->ignore_ui_cb = FALSE;
@@ -1019,7 +1017,7 @@ project_domain_changed (GladeProject           *project,
                         GParamSpec             *pspec,
                         GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   const gchar *domain;
 
   priv->ignore_ui_cb = TRUE;
@@ -1035,7 +1033,7 @@ project_resource_path_changed (GladeProject           *project,
                                GParamSpec             *pspec,
                                GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   priv->ignore_ui_cb = TRUE;
   update_prefs_for_resource_path (properties);
   priv->ignore_ui_cb = FALSE;
@@ -1046,7 +1044,7 @@ project_template_changed (GladeProject           *project,
                           GParamSpec             *pspec,
                           GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   GtkTreeModel *model;
   GtkTreeIter iter;
   gboolean valid;
@@ -1101,7 +1099,7 @@ project_license_changed (GladeProject           *project,
                          GParamSpec             *pspec,
                          GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
 
   priv->ignore_ui_cb = TRUE;  
   gtk_text_buffer_set_text (priv->license_textbuffer, 
@@ -1115,7 +1113,7 @@ project_css_provider_path_changed (GladeProject           *project,
                                    GParamSpec             *pspec,
                                    GladeProjectProperties *properties)
 {
-  GladeProjectPropertiesPrivate *priv = properties->priv;
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(properties);
   const gchar *filename = glade_project_get_css_provider_path (project);
   GtkFileChooser *chooser = GTK_FILE_CHOOSER (priv->css_filechooser);
 
@@ -1147,19 +1145,21 @@ _glade_project_properties_set_license_data (GladeProjectProperties *props,
                                             const gchar *copyright,
                                             const gchar *authors)
 {
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(props);
+
   if (!license ||
-      !gtk_combo_box_set_active_id (props->priv->license_comboboxtext, license))
+      !gtk_combo_box_set_active_id (priv->license_comboboxtext, license))
     {
-      gtk_combo_box_set_active_id (props->priv->license_comboboxtext, "other");
+      gtk_combo_box_set_active_id (priv->license_comboboxtext, "other");
       name = description = copyright = authors = "";
       license = "other";
     }
         
-  gtk_entry_buffer_set_text (props->priv->name_entrybuffer, name ? name : "", -1);
-  gtk_entry_buffer_set_text (props->priv->description_entrybuffer, description ? description : "", -1);
+  gtk_entry_buffer_set_text (priv->name_entrybuffer, name ? name : "", -1);
+  gtk_entry_buffer_set_text (priv->description_entrybuffer, description ? description : "", -1);
 
-  gtk_text_buffer_set_text (props->priv->copyright_textbuffer, copyright ? copyright : "", -1);
-  gtk_text_buffer_set_text (props->priv->authors_textbuffer, authors ? authors : "", -1);
+  gtk_text_buffer_set_text (priv->copyright_textbuffer, copyright ? copyright : "", -1);
+  gtk_text_buffer_set_text (priv->authors_textbuffer, authors ? authors : "", -1);
 
   gpp_update_license (props, gpp_get_license_from_id (license));
 }
@@ -1172,7 +1172,8 @@ _glade_project_properties_get_license_data (GladeProjectProperties *props,
                                             gchar **copyright,
                                             gchar **authors)
 {
-  const gchar *id = gtk_combo_box_get_active_id (props->priv->license_comboboxtext);
+  GladeProjectPropertiesPrivate *priv = GLADE_PROJECT_PROPERTIES_PRIVATE(props);
+  const gchar *id = gtk_combo_box_get_active_id (priv->license_comboboxtext);
 
   if (!g_strcmp0 (id, "other"))
     {
@@ -1181,11 +1182,11 @@ _glade_project_properties_get_license_data (GladeProjectProperties *props,
     }
 
   *license = g_strdup (id);
-  *name = g_strdup (gtk_entry_buffer_get_text (props->priv->name_entrybuffer));
-  *description = g_strdup (gtk_entry_buffer_get_text (props->priv->description_entrybuffer));
+  *name = g_strdup (gtk_entry_buffer_get_text (priv->name_entrybuffer));
+  *description = g_strdup (gtk_entry_buffer_get_text (priv->description_entrybuffer));
 
-  g_object_get (props->priv->copyright_textbuffer, "text", copyright, NULL);
-  g_object_get (props->priv->authors_textbuffer, "text", authors, NULL);
+  g_object_get (priv->copyright_textbuffer, "text", copyright, NULL);
+  g_object_get (priv->authors_textbuffer, "text", authors, NULL);
 }
 
 /******************************************************
