@@ -38,6 +38,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gi18n-lib.h>
+#include <locale.h>
 
 #include "glade.h"
 #include "glade-widget.h"
@@ -235,9 +236,9 @@ glade_property_def_new (GladeWidgetAdaptor *adaptor,
   property_def->create_type = NULL;
 
   /* Initialize property versions & deprecated to adaptor */
-  property_def->version_since_major = GWA_VERSION_SINCE_MAJOR (adaptor);
-  property_def->version_since_minor = GWA_VERSION_SINCE_MINOR (adaptor);
-  property_def->deprecated          = GWA_DEPRECATED (adaptor);
+  property_def->version_since_major = GLADE_WIDGET_ADAPTOR_VERSION_SINCE_MAJOR (adaptor);
+  property_def->version_since_minor = GLADE_WIDGET_ADAPTOR_VERSION_SINCE_MINOR (adaptor);
+  property_def->deprecated          = GLADE_WIDGET_ADAPTOR_DEPRECATED (adaptor);
 
   return property_def;
 }
@@ -452,6 +453,21 @@ glade_property_def_make_string_from_objects (GladePropertyDef *
   return string;
 }
 
+static locale_t
+get_C_locale (void)
+{
+  static gsize initialized = FALSE;
+  static locale_t C_locale = NULL;
+
+  if (g_once_init_enter (&initialized))
+    {
+      C_locale = newlocale (LC_ALL_MASK, "C", NULL);
+      g_once_init_leave (&initialized, TRUE);
+    }
+
+  return C_locale;
+}
+
 static gchar *
 glade_dtostr (double number, gdouble epsilon)
 {
@@ -461,8 +477,10 @@ glade_dtostr (double number, gdouble epsilon)
   for (i = 0; i <= 20; i++)
     {
       double rounded;
-
+      locale_t old_locale;
+      old_locale = uselocale (get_C_locale ());
       snprintf (str, G_ASCII_DTOSTR_BUF_SIZE, "%.*f", i, number);
+      uselocale (old_locale);
       rounded = g_ascii_strtod (str, NULL);
 
       if (ABS (rounded - number) <= epsilon)
@@ -490,20 +508,10 @@ glade_property_def_make_string_from_gvalue (GladePropertyDef *
   GdkRGBA *rgba;
   GList *objects;
 
-  if (G_IS_PARAM_SPEC_ENUM (property_def->pspec))
-    {
-      gint eval = g_value_get_enum (value);
-      string = glade_property_def_make_string_from_enum
-          (property_def->pspec->value_type, eval);
-    }
-  else if (G_IS_PARAM_SPEC_FLAGS (property_def->pspec))
-    {
-      guint flags = g_value_get_flags (value);
-      string = glade_property_def_make_string_from_flags
-          (property_def, flags, FALSE);
-    }
-  else if (G_IS_PARAM_SPEC_VALUE_ARRAY (property_def->pspec))
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  if (GLADE_PROPERTY_IS_PARAM_SPEC_VALUE_ARRAY (property_def->pspec))
     {
+      G_GNUC_END_IGNORE_DEPRECATIONS;
       GValueArray *value_array = g_value_get_boxed (value);
 
       if (value_array && value_array->n_values &&
@@ -522,6 +530,18 @@ glade_property_def_make_string_from_gvalue (GladePropertyDef *
           g_string_free (gstring, FALSE);
         }
     }
+  else if (G_IS_PARAM_SPEC_ENUM (property_def->pspec))
+    {
+      gint eval = g_value_get_enum (value);
+      string = glade_property_def_make_string_from_enum
+          (property_def->pspec->value_type, eval);
+    }
+  else if (G_IS_PARAM_SPEC_FLAGS (property_def->pspec))
+    {
+      guint flags = g_value_get_flags (value);
+      string = glade_property_def_make_string_from_flags
+          (property_def, flags, FALSE);
+    }
   else if (G_IS_PARAM_SPEC_BOXED (property_def->pspec))
     {
       if (property_def->pspec->value_type == GDK_TYPE_COLOR)
@@ -825,20 +845,10 @@ glade_property_def_make_gvalue_from_string (GladePropertyDef *property_def,
 
   g_value_init (value, property_def->pspec->value_type);
 
-  if (G_IS_PARAM_SPEC_ENUM (property_def->pspec))
-    {
-      gint eval = glade_property_def_make_enum_from_string
-          (property_def->pspec->value_type, string);
-      g_value_set_enum (value, eval);
-    }
-  else if (G_IS_PARAM_SPEC_FLAGS (property_def->pspec))
-    {
-      guint flags = glade_property_def_make_flags_from_string
-          (property_def->pspec->value_type, string);
-      g_value_set_flags (value, flags);
-    }
-  else if (G_IS_PARAM_SPEC_VALUE_ARRAY (property_def->pspec))
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  if (GLADE_PROPERTY_IS_PARAM_SPEC_VALUE_ARRAY (property_def->pspec))
     {
+      G_GNUC_END_IGNORE_DEPRECATIONS;
       GValueArray *value_array;
       GValue str_value = { 0, };
       gint i;
@@ -862,6 +872,18 @@ glade_property_def_make_gvalue_from_string (GladePropertyDef *property_def,
       g_value_take_boxed (value, value_array);
       g_strfreev (strv);
     }
+  else if (G_IS_PARAM_SPEC_ENUM (property_def->pspec))
+    {
+      gint eval = glade_property_def_make_enum_from_string
+          (property_def->pspec->value_type, string);
+      g_value_set_enum (value, eval);
+    }
+  else if (G_IS_PARAM_SPEC_FLAGS (property_def->pspec))
+    {
+      guint flags = glade_property_def_make_flags_from_string
+          (property_def->pspec->value_type, string);
+      g_value_set_flags (value, flags);
+    }
   else if (G_IS_PARAM_SPEC_BOXED (property_def->pspec))
     {
       if (property_def->pspec->value_type == GDK_TYPE_COLOR)
