@@ -299,7 +299,7 @@ glade_util_check_and_warn_scrollable (GladeWidget *parent,
                                       GtkWidget *parent_widget)
 {
   if (GTK_IS_SCROLLED_WINDOW (glade_widget_get_object (parent)) &&
-      GWA_SCROLLABLE_WIDGET (child_adaptor) == FALSE)
+      GLADE_WIDGET_ADAPTOR_SCROLLABLE_WIDGET (child_adaptor) == FALSE)
     {
       GladeWidgetAdaptor *vadaptor =
           glade_widget_adaptor_get_by_type (GTK_TYPE_VIEWPORT);
@@ -907,7 +907,7 @@ try_load_library (const gchar *library_path, const gchar *library_name)
 }
 
 /**
- * glade_util_load_library:
+ * glade_util_load_library: (skip)
  * @library_name: name of the library
  *
  * Loads the named library from the Glade modules and lib directory or failing that
@@ -1473,9 +1473,9 @@ pdef_from_gtype (GType type)
                                    G_MININT8, G_MAXINT8, 0,
                                    G_PARAM_READABLE | G_PARAM_WRITABLE);
       else if (type == G_TYPE_UCHAR)
-        pspec = g_param_spec_char ("dummy", "dummy", "dummy",
-                                   0, G_MAXUINT8, 0,
-                                   G_PARAM_READABLE | G_PARAM_WRITABLE);
+        pspec = g_param_spec_uchar ("dummy", "dummy", "dummy",
+                                    0, G_MAXUINT8, 0,
+                                    G_PARAM_READABLE | G_PARAM_WRITABLE);
       else if (type == G_TYPE_BOOLEAN)
         pspec = g_param_spec_boolean ("dummy", "dummy", "dummy",
                                       FALSE,
