@@ -128,14 +128,14 @@ enum
   ACCEL_NUM_COLUMNS
 };
 
-typedef struct
+struct _GladeEPropAccel
 {
   GladeEditorProperty parent_instance;
 
   GtkWidget *entry;
   GList *parent_iters;
   GtkTreeModel *model;
-} GladeEPropAccel;
+} ;
 
 typedef struct
 {
@@ -143,13 +143,10 @@ typedef struct
   const gchar *name;                  /* <-- dont free */
 } GladeEpropIterTab;
 
-GLADE_MAKE_EPROP (GladeEPropAccel, glade_eprop_accel)
-#define GLADE_EPROP_ACCEL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GLADE_TYPE_EPROP_ACCEL, GladeEPropAccel))
-#define GLADE_EPROP_ACCEL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GLADE_TYPE_EPROP_ACCEL, GladeEPropAccelClass))
-#define GLADE_IS_EPROP_ACCEL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GLADE_TYPE_EPROP_ACCEL))
-#define GLADE_IS_EPROP_ACCEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GLADE_TYPE_EPROP_ACCEL))
-#define GLADE_EPROP_ACCEL_GET_CLASS(o)    (G_TYPE_INSTANCE_GET_CLASS ((o), GLADE_EPROP_ACCEL, GladeEPropAccelClass))
-     static void glade_eprop_accel_finalize (GObject * object)
+GLADE_MAKE_EPROP (GladeEPropAccel, glade_eprop_accel, GLADE, EPROP_ACCEL)
+
+static void
+glade_eprop_accel_finalize (GObject * object)
 {
   /* Chain up */
   GObjectClass *parent_class =
@@ -201,10 +198,10 @@ glade_eprop_accel_populate_view (GladeEditorProperty * eprop,
                                  GtkTreeView * view)
 {
   GladeEPropAccel *eprop_accel = GLADE_EPROP_ACCEL (eprop);
-  GladeSignalClass *sclass;
-  GladePropertyClass *pclass = glade_editor_property_get_pclass (eprop);
+  GladeSignalDef *sdef;
+  GladePropertyDef   *pdef = glade_editor_property_get_property_def (eprop);
   GladeProperty      *property = glade_editor_property_get_property (eprop);
-  GladeWidgetAdaptor *adaptor = glade_property_class_get_adaptor (pclass);
+  GladeWidgetAdaptor *adaptor = glade_property_def_get_adaptor (pdef);
   GtkTreeStore *model = (GtkTreeStore *) gtk_tree_view_get_model (view);
   GtkTreeIter iter;
   GladeEpropIterTab *parent_tab;
@@ -222,32 +219,32 @@ G_GNUC_END_IGNORE_DEPRECATIONS
    */
   for (list = glade_widget_adaptor_get_signals (adaptor); list; list = list->next)
     {
-      sclass = list->data;
+      sdef = list->data;
 
       /* Special case for GtkAction accelerators  */
       if (glade_widget_adaptor_get_object_type (adaptor) == type_action ||
           g_type_is_a (glade_widget_adaptor_get_object_type (adaptor), type_action))
         {
-          if (g_strcmp0 (glade_signal_class_get_type (sclass), "GtkAction") != 0 ||
-              g_strcmp0 (glade_signal_class_get_name (sclass), "activate") != 0)
+          if (g_strcmp0 (glade_signal_def_get_object_type_name (sdef), "GtkAction") != 0 ||
+              g_strcmp0 (glade_signal_def_get_name (sdef), "activate") != 0)
             continue;
         }
       /* Only action signals have accelerators. */
-      else if ((glade_signal_class_get_flags (sclass) & G_SIGNAL_ACTION) == 0)
+      else if ((glade_signal_def_get_flags (sdef) & G_SIGNAL_ACTION) == 0)
         continue;
 
       if (g_list_find_custom (eprop_accel->parent_iters,
-                              glade_signal_class_get_type (sclass),
+                              glade_signal_def_get_object_type_name (sdef),
                               (GCompareFunc) eprop_find_iter) == NULL)
         {
           gtk_tree_store_append (model, &iter, NULL);
           gtk_tree_store_set (model, &iter,
-                              ACCEL_COLUMN_SIGNAL, glade_signal_class_get_type (sclass),
+                              ACCEL_COLUMN_SIGNAL, glade_signal_def_get_object_type_name (sdef),
                               ACCEL_COLUMN_WEIGHT, PANGO_WEIGHT_BOLD,
                               ACCEL_COLUMN_VISIBLE, FALSE, -1);
 
           parent_tab = g_new0 (GladeEpropIterTab, 1);
-          parent_tab->name = glade_signal_class_get_type (sclass);
+          parent_tab->name = glade_signal_def_get_object_type_name (sdef);
           parent_tab->iter = gtk_tree_iter_copy (&iter);
 
           eprop_accel->parent_iters =
@@ -259,26 +256,26 @@ G_GNUC_END_IGNORE_DEPRECATIONS
    */
   for (list = glade_widget_adaptor_get_signals (adaptor); list; list = list->next)
     {
-      sclass = list->data;
+      sdef = list->data;
 
       /* Special case for GtkAction accelerators  */
       if (glade_widget_adaptor_get_object_type (adaptor) == type_action ||
           g_type_is_a (glade_widget_adaptor_get_object_type (adaptor), type_action))
         {
-          if (g_strcmp0 (glade_signal_class_get_type (sclass), "GtkAction") != 0 ||
-              g_strcmp0 (glade_signal_class_get_name (sclass), "activate") != 0)
+          if (g_strcmp0 (glade_signal_def_get_object_type_name (sdef), "GtkAction") != 0 ||
+              g_strcmp0 (glade_signal_def_get_name (sdef), "activate") != 0)
             continue;
         }
       /* Only action signals have accelerators. */
-      else if ((glade_signal_class_get_flags (sclass) & G_SIGNAL_ACTION) == 0)
+      else if ((glade_signal_def_get_flags (sdef) & G_SIGNAL_ACTION) == 0)
         continue;
 
       if ((found = g_list_find_custom (eprop_accel->parent_iters,
-                                       glade_signal_class_get_type (sclass),
+                                       glade_signal_def_get_object_type_name (sdef),
                                        (GCompareFunc) eprop_find_iter)) != NULL)
         {
           parent_tab = found->data;
-          name = g_strdup_printf ("    %s", glade_signal_class_get_name (sclass));
+          name = g_strdup_printf ("    %s", glade_signal_def_get_name (sdef));
 
           /* Populate from accelerator list
            */
@@ -286,7 +283,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
             {
               info = l->data;
 
-              if (g_strcmp0 (info->signal, glade_signal_class_get_name (sclass)))
+              if (g_strcmp0 (info->signal, glade_signal_def_get_name (sdef)))
                 continue;
 
               accel_text = gtk_accelerator_name (info->key, info->modifiers);
@@ -295,7 +292,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
               gtk_tree_store_set
                   (model, &iter,
                    ACCEL_COLUMN_SIGNAL, name,
-                   ACCEL_COLUMN_REAL_SIGNAL, glade_signal_class_get_name (sclass),
+                   ACCEL_COLUMN_REAL_SIGNAL, glade_signal_def_get_name (sdef),
                    ACCEL_COLUMN_TEXT, accel_text,
                    ACCEL_COLUMN_WEIGHT, PANGO_WEIGHT_NORMAL,
                    ACCEL_COLUMN_STYLE, PANGO_STYLE_NORMAL,
@@ -319,7 +316,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
           gtk_tree_store_set
               (model, &iter,
                ACCEL_COLUMN_SIGNAL, name,
-               ACCEL_COLUMN_REAL_SIGNAL, glade_signal_class_get_name (sclass),
+               ACCEL_COLUMN_REAL_SIGNAL, glade_signal_def_get_name (sdef),
                ACCEL_COLUMN_TEXT, _("<choose a key>"),
                ACCEL_COLUMN_WEIGHT, PANGO_WEIGHT_NORMAL,
                ACCEL_COLUMN_STYLE, PANGO_STYLE_ITALIC,
@@ -343,15 +340,15 @@ accel_edited (GtkCellRendererAccel * accel,
   gboolean key_was_set;
   GtkTreeIter iter, parent_iter, new_iter;
   gchar *accel_text;
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
   GladeWidgetAdaptor *adaptor;
   gboolean is_action;
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GType type_action = GTK_TYPE_ACTION;
 G_GNUC_END_IGNORE_DEPRECATIONS
 
-  pclass = glade_editor_property_get_pclass (GLADE_EDITOR_PROPERTY (eprop_accel));
-  adaptor = glade_property_class_get_adaptor (pclass);
+  pdef = glade_editor_property_get_property_def (GLADE_EDITOR_PROPERTY (eprop_accel));
+  adaptor = glade_property_def_get_adaptor (pdef);
 
   if (!gtk_tree_model_get_iter_from_string (eprop_accel->model,
                                             &iter, path_string))
@@ -429,15 +426,15 @@ glade_eprop_accel_view (GladeEditorProperty * eprop)
 
   eprop_accel->model = (GtkTreeModel *) 
     gtk_tree_store_new (ACCEL_NUM_COLUMNS, G_TYPE_STRING,   /* The GSignal name formatted for display */
-			G_TYPE_STRING,      /* The GSignal name */
-			G_TYPE_STRING,      /* The text to show in the accelerator cell */
-			G_TYPE_INT, /* PangoWeight attribute for bold headers */
-			G_TYPE_INT, /* PangoStyle attribute for italic grey unset items */
-			G_TYPE_STRING,      /* Foreground colour for italic grey unset items */
-			G_TYPE_BOOLEAN,     /* Visible attribute to hide items for header entries */
-			G_TYPE_BOOLEAN,     /* Whether the key has been entered for this row */
-			G_TYPE_UINT,        /* Hardware keycode */
-			G_TYPE_INT);        /* GdkModifierType */
+                        G_TYPE_STRING,      /* The GSignal name */
+                        G_TYPE_STRING,      /* The text to show in the accelerator cell */
+                        G_TYPE_INT, /* PangoWeight attribute for bold headers */
+                        G_TYPE_INT, /* PangoStyle attribute for italic grey unset items */
+                        G_TYPE_STRING,      /* Foreground colour for italic grey unset items */
+                        G_TYPE_BOOLEAN,     /* Visible attribute to hide items for header entries */
+                        G_TYPE_BOOLEAN,     /* Whether the key has been entered for this row */
+                        G_TYPE_UINT,        /* Hardware keycode */
+                        G_TYPE_INT);        /* GdkModifierType */
   
   view_widget = gtk_tree_view_new_with_model (eprop_accel->model);
   gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (view_widget), FALSE);
