@@ -88,20 +88,16 @@ glade_attr_glist_get_type (void)
 /**************************************************************
  *              GladeEditorProperty stuff here
  **************************************************************/
-typedef struct
+struct _GladeEPropAttrs
 {
   GladeEditorProperty parent_instance;
 
   GtkTreeModel *model;
 
-} GladeEPropAttrs;
+};
+
+GLADE_MAKE_EPROP (GladeEPropAttrs, glade_eprop_attrs, GLADE, EPROP_ATTRS)
 
-GLADE_MAKE_EPROP (GladeEPropAttrs, glade_eprop_attrs)
-#define GLADE_EPROP_ATTRS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GLADE_TYPE_EPROP_ATTRS, GladeEPropAttrs))
-#define GLADE_EPROP_ATTRS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GLADE_TYPE_EPROP_ATTRS, GladeEPropAttrsClass))
-#define GLADE_IS_EPROP_ATTRS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GLADE_TYPE_EPROP_ATTRS))
-#define GLADE_IS_EPROP_ATTRS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GLADE_TYPE_EPROP_ATTRS))
-#define GLADE_EPROP_ATTRS_GET_CLASS(o)    (G_TYPE_INSTANCE_GET_CLASS ((o), GLADE_EPROP_ATTRS, GladeEPropAttrsClass))
 enum
 {
 
@@ -121,13 +117,14 @@ enum
   COLUMN_BUTTON_ACTIVE,    /* whether the GladeCellRendererButton is to be used (to launch dialogs) */
   COLUMN_TEXT,             /* text attribute value for all text derived renderers */
   COLUMN_TEXT_STYLE,       /* whether to make italic */
-  COLUMN_TEXT_FG,          /* forground colour of the text */
+  COLUMN_TEXT_FG,          /* foreground colour of the text */
   
   COLUMN_COMBO_ACTIVE,     /* whether the combobox renderer is being used */
   COLUMN_COMBO_MODEL,      /* the model for the dropdown list */
   
   COLUMN_SPIN_ACTIVE,      /* whether the spin renderer is being used */
   COLUMN_SPIN_DIGITS,      /* How many decimal points to show (used to edit float values) */
+  COLUMN_SPIN_ADJUSTMENT,
 
   NUM_COLUMNS
 };
@@ -143,10 +140,10 @@ typedef enum
   EDIT_INVALID
 } AttrEditType;
 
-#define ACTIVATE_COLUMN_FROM_TYPE(type)                 \
-	((type) == EDIT_TOGGLE ? COLUMN_TOGGLE_ACTIVE : \
-	 (type) == EDIT_SPIN ? COLUMN_SPIN_ACTIVE :     \
-	 (type) == EDIT_COMBO ? COLUMN_COMBO_ACTIVE: COLUMN_BUTTON_ACTIVE)
+#define ACTIVATE_COLUMN_FROM_TYPE(type)           \
+  ((type) == EDIT_TOGGLE ? COLUMN_TOGGLE_ACTIVE : \
+   (type) == EDIT_SPIN ? COLUMN_SPIN_ACTIVE :     \
+   (type) == EDIT_COMBO ? COLUMN_COMBO_ACTIVE: COLUMN_BUTTON_ACTIVE)
 
 
 static GtkListStore *
@@ -208,6 +205,7 @@ append_empty_row (GtkListStore *store, PangoAttrType type)
 {
   const gchar *name = NULL;
   guint spin_digits = 0;
+  GtkAdjustment *adjustment = NULL;
   GtkListStore *model = get_enum_model_for_combo (type);
   GtkTreeIter iter;
   AttrEditType edit_type = EDIT_INVALID;
@@ -260,10 +258,12 @@ append_empty_row (GtkListStore *store, PangoAttrType type)
         /* PangoAttrSize */
       case PANGO_ATTR_SIZE:
         edit_type = EDIT_SPIN;
+        adjustment = gtk_adjustment_new (0, 0, PANGO_SCALE*PANGO_SCALE, PANGO_SCALE, 0, 0);
         name = C_ ("textattr", "Size");
         break;
       case PANGO_ATTR_ABSOLUTE_SIZE:
         edit_type = EDIT_SPIN;
+        adjustment = gtk_adjustment_new (0, 0, PANGO_SCALE*PANGO_SCALE, PANGO_SCALE, 0, 0);
         name = C_ ("textattr", "Absolute Size");
         break;
 
@@ -293,6 +293,7 @@ append_empty_row (GtkListStore *store, PangoAttrType type)
         /* PangoAttrFloat */
       case PANGO_ATTR_SCALE:
         edit_type = EDIT_SPIN;
+        adjustment = gtk_adjustment_new (0, 0, 128, 1, 0, 0);
         name = C_ ("textattr", "Scale");
         spin_digits = 3;
         break;
@@ -300,7 +301,7 @@ append_empty_row (GtkListStore *store, PangoAttrType type)
       case PANGO_ATTR_FONT_DESC:
         edit_type = EDIT_FONT;
         name = C_ ("textattr", "Font Description");
-	break;
+        break;
 
       case PANGO_ATTR_INVALID:
       case PANGO_ATTR_LETTER_SPACING:
@@ -330,6 +331,7 @@ append_empty_row (GtkListStore *store, PangoAttrType type)
                           COLUMN_TEXT_FG, "Grey",
                           COLUMN_COMBO_MODEL, model,
                           COLUMN_SPIN_DIGITS, spin_digits,
+                          COLUMN_SPIN_ADJUSTMENT, adjustment,
                           ACTIVATE_COLUMN_FROM_TYPE (edit_type), TRUE, -1);
       return TRUE;
     }
@@ -429,7 +431,7 @@ type_from_attr_type (PangoAttrType type)
       case PANGO_ATTR_UNDERLINE_COLOR:
       case PANGO_ATTR_STRIKETHROUGH_COLOR:
         /* boxed colours */
-        return GDK_TYPE_COLOR;
+        return PANGO_TYPE_COLOR;
 
         /* PangoAttrShape */
       case PANGO_ATTR_SHAPE:
@@ -453,7 +455,7 @@ glade_gtk_string_from_attr (GladeAttribute *gattr)
   gchar *ret = NULL;
   gint ival;
   gdouble fval;
-  GdkColor *color;
+  PangoColor *color;
 
   switch (gattr->type)
     {
@@ -511,7 +513,7 @@ glade_gtk_string_from_attr (GladeAttribute *gattr)
       case PANGO_ATTR_STRIKETHROUGH_COLOR:
         /* boxed colours */
         color = g_value_get_boxed (&(gattr->value));
-        ret = gdk_color_to_string (color);
+        ret = pango_color_to_string (color);
         break;
 
         /* PangoAttrShape */
@@ -534,7 +536,7 @@ GladeAttribute *
 glade_gtk_attribute_from_string (PangoAttrType type, const gchar *strval)
 {
   GladeAttribute *gattr;
-  GdkColor color;
+  PangoColor color;
 
   gattr = g_new0 (GladeAttribute, 1);
   gattr->type = type;
@@ -591,9 +593,9 @@ glade_gtk_attribute_from_string (PangoAttrType type, const gchar *strval)
       case PANGO_ATTR_UNDERLINE_COLOR:
       case PANGO_ATTR_STRIKETHROUGH_COLOR:
         /* boxed colours */
-        if (gdk_color_parse (strval, &color))
+        if (pango_color_parse (&color, strval))
           {
-            g_value_init (&(gattr->value), GDK_TYPE_COLOR);
+            g_value_init (&(gattr->value), PANGO_TYPE_COLOR);
             g_value_set_boxed (&(gattr->value), &color);
           }
         else
@@ -664,7 +666,7 @@ sync_object (GladeEPropAttrs *eprop_attrs, gboolean use_command)
   else
     {
       GladeProperty *property = 
-	glade_editor_property_get_property (GLADE_EDITOR_PROPERTY (eprop_attrs));
+        glade_editor_property_get_property (GLADE_EDITOR_PROPERTY (eprop_attrs));
 
       glade_property_set (property, g_list_reverse (attributes));
       glade_attr_list_free (attributes);
@@ -715,7 +717,7 @@ value_icon_activate (GtkCellRendererToggle *cell_renderer,
   gtk_tree_model_get (eprop_attrs->model, &iter,
                       COLUMN_TEXT, &text,
                       COLUMN_TYPE, &type, 
-		      COLUMN_EDIT_TYPE, &edit_type, -1);
+                      COLUMN_EDIT_TYPE, &edit_type, -1);
 
   /* Launch dialog etc. */
   switch (edit_type)
@@ -730,7 +732,7 @@ value_icon_activate (GtkCellRendererToggle *cell_renderer,
         if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
           {
             gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (dialog), &color);
-            /* Use GdkColor string format */
+            /* Use PangoColor string format */
             if (((guint8)(color.red * 0xFF)) * 0x101 == (guint16)(color.red * 0xFFFF) &&
                 ((guint8)(color.green * 0xFF)) * 0x101 == (guint16)(color.green * 0xFFFF) &&
                 ((guint8)(color.blue * 0xFF)) * 0x101 == (guint16)(color.blue * 0xFFFF))
@@ -859,29 +861,29 @@ glade_eprop_attrs_view (GladeEditorProperty *eprop)
   GtkWidget *view_widget;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkAdjustment *adjustment;
 
-  eprop_attrs->model = (GtkTreeModel *) 
+  eprop_attrs->model = (GtkTreeModel *)
     gtk_list_store_new (NUM_COLUMNS,
-			/* Main Data */
-			G_TYPE_STRING,      // COLUMN_NAME
-			G_TYPE_INT, // COLUMN_NAME_WEIGHT
-			G_TYPE_INT, // COLUMN_TYPE
-			G_TYPE_INT, // COLUMN_EDIT_TYPE
-			G_TYPE_POINTER,     // COLUMN_VALUE
-			G_TYPE_UINT,        // COLUMN_START
-			G_TYPE_UINT,        // COLUMN_END
-			/* Editor renderer related */
-			G_TYPE_BOOLEAN,     // COLUMN_TOGGLE_ACTIVE
-			G_TYPE_BOOLEAN,     // COLUMN_TOGGLE_DOWN
-			G_TYPE_BOOLEAN,     // COLUMN_BUTTON_ACTIVE
-			G_TYPE_STRING,      // COLUMN_TEXT
-			G_TYPE_INT, // COLUMN_TEXT_STYLE
-			G_TYPE_STRING,      // COLUMN_TEXT_FG
-			G_TYPE_BOOLEAN,     // COLUMN_COMBO_ACTIVE
-			GTK_TYPE_LIST_STORE,        // COLUMN_COMBO_MODEL
-			G_TYPE_BOOLEAN,     // COLUMN_SPIN_ACTIVE
-			G_TYPE_UINT);       // COLUMN_SPIN_DIGITS
+                        /* Main Data */
+                        G_TYPE_STRING,      // COLUMN_NAME
+                        G_TYPE_INT, // COLUMN_NAME_WEIGHT
+                        G_TYPE_INT, // COLUMN_TYPE
+                        G_TYPE_INT, // COLUMN_EDIT_TYPE
+                        G_TYPE_POINTER,     // COLUMN_VALUE
+                        G_TYPE_UINT,        // COLUMN_START
+                        G_TYPE_UINT,        // COLUMN_END
+                        /* Editor renderer related */
+                        G_TYPE_BOOLEAN,     // COLUMN_TOGGLE_ACTIVE
+                        G_TYPE_BOOLEAN,     // COLUMN_TOGGLE_DOWN
+                        G_TYPE_BOOLEAN,     // COLUMN_BUTTON_ACTIVE
+                        G_TYPE_STRING,      // COLUMN_TEXT
+                        G_TYPE_INT, // COLUMN_TEXT_STYLE
+                        G_TYPE_STRING,      // COLUMN_TEXT_FG
+                        G_TYPE_BOOLEAN,     // COLUMN_COMBO_ACTIVE
+                        GTK_TYPE_LIST_STORE,        // COLUMN_COMBO_MODEL
+                        G_TYPE_BOOLEAN,     // COLUMN_SPIN_ACTIVE
+                        G_TYPE_UINT,        // COLUMN_SPIN_DIGITS
+                        GTK_TYPE_ADJUSTMENT);// COLUMN_SPIN_ADJUSTMENT
   
   view_widget = gtk_tree_view_new_with_model (eprop_attrs->model);
   gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (view_widget), FALSE);
@@ -952,10 +954,6 @@ glade_eprop_attrs_view (GladeEditorProperty *eprop)
 
   /* Spin renderer */
   renderer = gtk_cell_renderer_spin_new ();
-  adjustment =
-      (GtkAdjustment *) gtk_adjustment_new (0, -G_MAXDOUBLE, G_MAXDOUBLE, 100,
-                                            100, 100);
-  g_object_set (G_OBJECT (renderer), "adjustment", adjustment, NULL);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer,
                                        "visible", COLUMN_SPIN_ACTIVE,
@@ -963,7 +961,9 @@ glade_eprop_attrs_view (GladeEditorProperty *eprop)
                                        "text", COLUMN_TEXT,
                                        "style", COLUMN_TEXT_STYLE,
                                        "foreground", COLUMN_TEXT_FG,
-                                       "digits", COLUMN_SPIN_DIGITS, NULL);
+                                       "digits", COLUMN_SPIN_DIGITS,
+                                       "adjustment", COLUMN_SPIN_ADJUSTMENT,
+                                       NULL);
   g_signal_connect (G_OBJECT (renderer), "edited",
                     G_CALLBACK (value_combo_spin_edited), eprop);
   g_signal_connect (G_OBJECT (renderer), "editing-started",
