@@ -61,13 +61,13 @@ column_types_store_populate_enums_flags (GtkListStore * store, gboolean enums)
   for (list = adaptors; list; list = list->next)
     {
       GladeWidgetAdaptor *adaptor = list->data;
-      GladePropertyClass *pclass;
+      GladePropertyDef   *pdef;
       GParamSpec         *pspec;
 
       for (l = glade_widget_adaptor_get_properties (adaptor); l; l = l->next)
         {
-          pclass = l->data;
-	  pspec  = glade_property_class_get_pspec (pclass);
+          pdef = l->data;
+          pspec  = glade_property_def_get_pspec (pdef);
 
           /* special case out a few of these... */
           if (strcmp (g_type_name (pspec->value_type),
@@ -225,7 +225,7 @@ glade_column_type_list_get_type (void)
 }
 
 /**************************** GladeEditorProperty *****************************/
-typedef struct
+struct _GladeEPropColumnTypes
 {
   GladeEditorProperty parent_instance;
 
@@ -241,15 +241,12 @@ typedef struct
 
   GtkTreeViewColumn *name_column;
   GtkTreeViewColumn *type_column;
-} GladeEPropColumnTypes;
+};
 
-GLADE_MAKE_EPROP (GladeEPropColumnTypes, glade_eprop_column_types)
-#define GLADE_EPROP_COLUMN_TYPES(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GLADE_TYPE_EPROP_COLUMN_TYPES, GladeEPropColumnTypes))
-#define GLADE_EPROP_COLUMN_TYPES_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GLADE_TYPE_EPROP_COLUMN_TYPES, GladeEPropColumnTypesClass))
-#define GLADE_IS_EPROP_COLUMN_TYPES(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GLADE_TYPE_EPROP_COLUMN_TYPES))
-#define GLADE_IS_EPROP_COLUMN_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GLADE_TYPE_EPROP_COLUMN_TYPES))
-#define GLADE_EPROP_COLUMN_TYPES_GET_CLASS(o)    (G_TYPE_INSTANCE_GET_CLASS ((o), GLADE_EPROP_COLUMN_TYPES, GladeEPropColumnTypesClass))
-     static void glade_eprop_column_types_finalize (GObject * object)
+GLADE_MAKE_EPROP (GladeEPropColumnTypes, glade_eprop_column_types, GLADE, EPROP_COLUMN_TYPES)
+
+static void
+glade_eprop_column_types_finalize (GObject * object)
 {
   /* Chain up */
   GObjectClass *parent_class =
@@ -328,7 +325,7 @@ eprop_column_adjust_rows (GladeEditorProperty * eprop, GList * columns)
 static void
 eprop_column_append (GladeEditorProperty *eprop,
                      const gchar         *type_name, 
-		     const gchar         *column_name)
+                     const gchar         *column_name)
 {
   GladeEPropColumnTypes *eprop_types = GLADE_EPROP_COLUMN_TYPES (eprop);
   GList *columns = NULL;
@@ -365,7 +362,7 @@ eprop_column_append (GladeEditorProperty *eprop,
 static gboolean
 eprop_treeview_key_press (GtkWidget           *treeview,
                           GdkEventKey         *event, 
-			  GladeEditorProperty *eprop)
+                          GladeEditorProperty *eprop)
 {
   /* Remove from list and commit value, dont touch the liststore except in load() */
   GladeEPropColumnTypes *eprop_types = GLADE_EPROP_COLUMN_TYPES (eprop);
@@ -665,7 +662,7 @@ column_name_edited (GtkCellRendererText * cell,
       strcmp (new_column_name, old_column_name) == 0)
     return;
 
-  /* Attempt to rename the column, and commit if successfull... */
+  /* Attempt to rename the column, and commit if successful... */
   glade_property_get (prop, &columns);
   if (columns)
     columns = glade_column_list_copy (columns);
@@ -810,7 +807,7 @@ glade_eprop_column_types_create_input (GladeEditorProperty * eprop)
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
 
-/* 	hbox = gtk_hbox_new (FALSE, 4); */
+/*  hbox = gtk_hbox_new (FALSE, 4); */
 
   if (!types_model)
     {
