@@ -43,7 +43,8 @@ glade_gtk_window_parse_finished (GladeProject *project, GObject *object)
 {
   GtkWidget *titlebar = gtk_window_get_titlebar(GTK_WINDOW (object));
   glade_widget_property_set (glade_widget_get_from_gobject (object), "use-csd",
-                             titlebar && gtk_widget_get_visible (titlebar));
+                             titlebar && gtk_widget_get_visible (titlebar) &&
+                             !GLADE_IS_PLACEHOLDER (titlebar));
 }
 
 static void
@@ -153,7 +154,7 @@ glade_gtk_window_read_widget (GladeWidgetAdaptor *adaptor,
     return;
 
   /* First chain up and read in all the normal properties.. */
-  GWA_GET_CLASS (GTK_TYPE_WIDGET)->read_widget (adaptor, widget, node);
+  GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->read_widget (adaptor, widget, node);
 
   /* Sync the icon mode */
   if (glade_widget_property_original_default (widget, "icon") == FALSE)
@@ -205,9 +206,8 @@ glade_gtk_window_write_widget (GladeWidgetAdaptor *adaptor,
         glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
-  /* First chain up and read in all the normal properties.. */
-  GWA_GET_CLASS (GTK_TYPE_WIDGET)->write_widget (adaptor, widget, context,
-                                                 node);
+  /* First chain up and write in all the normal properties.. */
+  GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->write_widget (adaptor, widget, context, node);
 
   glade_gtk_window_write_accel_groups (widget, context, node);
 }
@@ -242,7 +242,7 @@ glade_gtk_window_create_editable (GladeWidgetAdaptor *adaptor,
         editable = (GladeEditable *) glade_window_editor_new ();
     }
   else
-    editable = GWA_GET_CLASS (GTK_TYPE_WIDGET)->create_editable (adaptor, type);
+    editable = GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WIDGET)->create_editable (adaptor, type);
 
   return editable;
 }
@@ -282,8 +282,19 @@ glade_gtk_window_set_property (GladeWidgetAdaptor *adaptor,
         }
       else
         {
-          /* Set a hidden placeholder as the titlebar */
-          glade_gtk_window_ensure_titlebar_placeholder (object);
+          if (GLADE_IS_PLACEHOLDER (titlebar))
+            gtk_widget_hide (titlebar);
+          else
+            {
+              GList this_widget = { 0, };
+
+              /* Remove titlebar widget */
+              this_widget.data = glade_widget_get_from_gobject (titlebar);
+              glade_command_delete (&this_widget);
+
+              /* Set a hidden placeholder as the titlebar */
+              glade_gtk_window_ensure_titlebar_placeholder (object);
+            }
 
           glade_widget_property_set_sensitive (gwidget, "title", TRUE, NULL);
           glade_widget_property_set_sensitive (gwidget, "decorated", TRUE, NULL);
@@ -291,7 +302,7 @@ glade_gtk_window_set_property (GladeWidgetAdaptor *adaptor,
         }
     }
   else
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
 }
 
 void
@@ -312,7 +323,7 @@ glade_gtk_window_replace_child (GladeWidgetAdaptor *adaptor,
     }
 
   /* Chain Up */
-  GWA_GET_CLASS
+  GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS
       (GTK_TYPE_CONTAINER)->replace_child (adaptor,
                                            G_OBJECT (container),
                                            G_OBJECT (current),
