@@ -47,15 +47,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#ifdef MAC_INTEGRATION
-#  include <gtkosxapplication.h>
-#endif
-
-
-#define ACTION_GROUP_STATIC             "GladeStatic"
-#define ACTION_GROUP_PROJECT            "GladeProject"
-#define ACTION_GROUP_PROJECTS_LIST_MENU "GladeProjectsList"
-
 #define READONLY_INDICATOR (_("[Read Only]"))
 
 #define URL_DEVELOPER_MANUAL "http://library.gnome.org/devel/gladeui/"
@@ -69,11 +60,6 @@
 #define CONFIG_KEY_HEIGHT           "height"
 #define CONFIG_KEY_MAXIMIZED        "maximized"
 
-#define CONFIG_GROUP_LOAD_SAVE      "Load and Save"
-#define CONFIG_KEY_BACKUP           "backup"
-#define CONFIG_KEY_AUTOSAVE         "autosave"
-#define CONFIG_KEY_AUTOSAVE_SECONDS "autosave-seconds"
-
 #define CONFIG_INTRO_GROUP          "Intro"
 #define CONFIG_INTRO_DONE           "intro-done"
 
@@ -2115,16 +2101,18 @@ static void
 glade_window_init (GladeWindow *window)
 {
   GladeWindowPrivate *priv;
+  GtkStyleContext *ctx;
 
   window->priv = priv = glade_window_get_instance_private (window);
 
   priv->default_path = NULL;
 
+  /* This will load extra catalog paths */
   priv->settings = glade_settings_new ();
   glade_settings_load (priv->settings, glade_app_get_config ());
 
-  /* We need this for the icons to be available */
-  glade_init ();
+  /* Create GladeApp singleton, this will load all catalogs and load icons */
+  priv->app = glade_app_new ();
 
   gtk_widget_init_template (GTK_WIDGET (window));
 
@@ -2132,6 +2120,10 @@ glade_window_init (GladeWindow *window)
   gtk_box_set_homogeneous (GTK_BOX (priv->save_button_box), FALSE);
 
   priv->registration = glade_registration_new ();
+
+  /* Add Gdk backend as a class */
+  ctx = gtk_widget_get_style_context (GTK_WIDGET (window));
+  gtk_style_context_add_class (ctx, glade_window_get_gdk_backend ());
 }
 
 static void
@@ -2417,15 +2409,11 @@ glade_window_constructed (GObject *object)
   g_signal_connect (G_OBJECT (window), "key-press-event",
                     G_CALLBACK (glade_utils_hijack_key_press), window);
 
-  /* Load configuration, we need the list of extra catalog paths before creating
-   * the GladeApp
-   */
-  glade_window_config_load (window);
-
-  /* Create GladeApp singleton, this will load all catalogs */
-  priv->app = glade_app_new ();
   glade_app_set_window (GTK_WIDGET (window));
 
+  /* Load configuration */
+  glade_window_config_load (window);
+
   /* Clipboard signals */
   g_signal_connect (G_OBJECT (glade_app_get_clipboard ()),
                     "notify::has-selection",
@@ -2572,3 +2560,63 @@ glade_window_registration_notify_user (GladeWindow *window)
                               /* translators: Text to show in the statusbar if the user did not completed the survey and choose not to show the notification dialog again */
                               _("Go to Help -> Registration & User Survey and complete our survey!"));
 }
+
+#ifdef GDK_WINDOWING_X11
+#include "gdk/gdkx.h"
+#endif
+
+#ifdef GDK_WINDOWING_QUARTZ
+#include "gdk/gdkquartz.h"
+#endif
+
+#ifdef GDK_WINDOWING_WIN32
+#include "gdk/gdkwin32.h"
+#endif
+
+#ifdef GDK_WINDOWING_WAYLAND
+#include "gdk/gdkwayland.h"
+#endif
+
+#ifdef GDK_WINDOWING_BROADWAY
+#include "gdk/gdkbroadway.h"
+#endif
+
+const gchar *
+glade_window_get_gdk_backend ()
+{
+  GdkDisplay *display = gdk_display_get_default ();
+
+#ifdef GDK_WINDOWING_X11
+  if (GDK_IS_X11_DISPLAY (display))
+    return "X11";
+  else
+#endif
+
+#ifdef GDK_WINDOWING_QUARTZ
+  if (GDK_IS_QUARTZ_DISPLAY (display))
+    return "Quartz";
+  else
+#endif
+
+#ifdef GDK_WINDOWING_WIN32
+  if (GDK_IS_WIN32_DISPLAY (display))
+    return "Win32";
+  else
+#endif
+
+#ifdef GDK_WINDOWING_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (display))
+    return "Wayland";
+  else
+#endif
+
+#ifdef GDK_WINDOWING_BROADWAY
+  if (GDK_IS_BROADWAY_DISPLAY (display))
+    return "Broadway";
+  else
+#endif
+  {
+    return "Unknown";
+  }
+}
+
